@@ -2,10 +2,10 @@
 
 #
 # Blackmagic Fusion Multi Debian package creator
-# Release 2020-10-31
+# Release 2020-11-12
 # By Daniel Tufvesson
 #
-MAKEFUSIONDEB_VERSION=1.0
+MAKEFUSIONDEB_VERSION=1.1
 
 check_command() {
     echo -n "Checking for ${1}..."
@@ -131,7 +131,7 @@ process9() {
     copy_object ${UNPACK_DIR}/Templates.zip ${FUSION_VAR_DIR}
 }
 
-process16() {
+process1617() {
     # Copy objects
     copy_object ${UNPACK_DIR}/Fusion ${FUSION_BASE_DIR}
     copy_object ${UNPACK_DIR}/FusionServer ${FUSION_BASE_DIR}
@@ -242,13 +242,17 @@ case $FUSION_VERSION in
 	process9
 	;;
     16.*)
-	echo "Using Fusion 16 conversion process"
-	process16
+	echo "Using Fusion 16/17 conversion process"
+	process1617
+	;;
+    17.*)
+	echo "Using Fusion 16/17 conversion process"
+	process1617
 	;;
     *)
 	echo "Unknown Fusion version"
-	echo "Trying Fusion 16 conversion process"
-	process16
+	echo "Trying Fusion 16/17 conversion process"
+	process1617
 	;;
 esac
 
